Class: Node::EVSTR
- Defined in:
- ext/nodeinfo.c,
ext/cached/ruby-1.6.3/nodeinfo.c,
ext/cached/ruby-1.6.4/nodeinfo.c,
ext/cached/ruby-1.6.5/nodeinfo.c,
ext/cached/ruby-1.6.7/nodeinfo.c,
ext/cached/ruby-1.6.8/nodeinfo.c,
ext/cached/ruby-1.8.0/nodeinfo.c,
ext/cached/ruby-1.8.1/nodeinfo.c,
ext/cached/ruby-1.8.2/nodeinfo.c,
ext/cached/ruby-1.8.3/nodeinfo.c,
ext/cached/ruby-1.8.4/nodeinfo.c,
ext/cached/ruby-1.8.5/nodeinfo.c,
ext/cached/ruby-1.8.6/nodeinfo.c
Class Method Summary collapse
-
.members ⇒ Object
Return an array of strings containing the names of the node class’s members.
Instance Method Summary collapse
-
#body ⇒ Object
Return the Node’s body member.
-
#lit ⇒ Object
Return the Node’s lit member.
Methods inherited from Node
#[], #_dump, _load, #address, #as_code, #as_expression, #as_paren_expression, #bytecode_compile, compile_string, define_code, define_expression, #eval, #flags, #inspect, #members, #nd_file, #nd_line, #nd_type, #pretty_print, #tree
Class Method Details
.members ⇒ Object
Return an array of strings containing the names of the node class’s members.
2076 2077 2078 2079 |
# File 'ext/nodeinfo.c', line 2076 VALUE node_s_members(VALUE klass) { return rb_iv_get(klass, "__member__"); } |
Instance Method Details
#body ⇒ Object
Return the Node’s body member. The return type is either a Node or an Object.
1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 |
# File 'ext/nodeinfo.c', line 1524 static VALUE node_body(VALUE self) { NODE * n; Data_Get_Struct(self, NODE, n); if(TYPE(n->nd_body) == T_NODE) { return wrap_node((NODE *)n->nd_body); } else { return (VALUE)n->nd_body; } } |
#lit ⇒ Object
Return the Node’s lit member. The return type is either a Node or an Object.
1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 |
# File 'ext/cached/ruby-1.6.3/nodeinfo.c', line 1781 static VALUE node_lit(VALUE self) { NODE * n; Data_Get_Struct(self, NODE, n); if(TYPE(n->nd_lit) == T_NODE) { return wrap_node((NODE *)n->nd_lit); } else { return (VALUE)n->nd_lit; } } |